# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class CreateAssetResponseOut(UniversalBaseModel):
    """
    Response model for asset creation.
    """

    asset_id: str = pydantic.Field()
    """
    ID of the newly created asset
    """

    asset_type: str = pydantic.Field()
    """
    Type of the created asset
    """

    created_at: str = pydantic.Field()
    """
    Timestamp when the asset was created
    """

    parent_folder_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    ID of the parent folder
    """

    title: str = pydantic.Field()
    """
    Title of the created asset
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
